xarxa

Crates

git

Versions

default

Flavors

Routes

Struct Routes 

pub struct Routes { /* private fields */ }
A routing table.

Implementations

Source

impl Routes

pub fn add(&mut self, route: Route) -> Result<(), Full>

Add a route.

Errors:

  • Full if the table has no room. Only possible without the alloc feature, where the limit is ROUTE_COUNT.
pub fn remove(&mut self, index: usize) -> Route

Remove the route at index and return it.

Panics

Panics if index is out of bounds.

pub fn retain(&mut self, f: impl FnMut(&Route) -> bool)

Keep only the routes for which f returns true.

pub fn clear(&mut self)

Remove all routes.

pub fn iter(&self) -> impl Iterator<Item = &Route>

Iterate over the routes.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Route>

Iterate over the routes, mutably.

pub fn len(&self) -> usize

Number of routes.

pub fn is_empty(&self) -> bool

Whether there are no routes.

pub fn add_default_ipv4_route( &mut self, gateway: Ipv4Address, iface: IfaceHandle, ) -> Result<Option<Route>, Full>

Add a default ipv4 gateway (ie. “ip route add 0.0.0.0/0 via gateway dev iface”).

Returns the previous default route, if any.

Errors:

  • Full if the table has no room. Only possible without the alloc feature, where the limit is ROUTE_COUNT.
pub fn add_default_ipv6_route( &mut self, gateway: Ipv6Address, iface: IfaceHandle, ) -> Result<Option<Route>, Full>

Add a default ipv6 gateway (ie. “ip -6 route add ::/0 via gateway dev iface”).

Returns the previous default route, if any.

Errors:

  • Full if the table has no room. Only possible without the alloc feature, where the limit is ROUTE_COUNT.
pub fn get_default_ipv4_route(&self) -> Option<Route>

Returns the ipv4 default route if there is one in the route table.

pub fn get_default_ipv6_route(&self) -> Option<Route>

Returns the ipv6 default route if there is one in the route table.

pub fn remove_default_ipv4_route(&mut self) -> Option<Route>

Remove the default ipv4 gateway, returning it if it existed.

pub fn remove_default_ipv6_route(&mut self) -> Option<Route>

Remove the default ipv6 gateway, returning it if it existed.